pub struct WeightSlot {
pub name: String,
pub forward_id: NodeId,
pub offset: usize,
pub size: usize,
}Expand description
One named parameter and its byte range in the shared weight region.
Fields
name: Stringforward_id: NodeIdoffset: usizesize: usizeTrait Implementations
Sourceimpl Clone for WeightSlot
impl Clone for WeightSlot
Sourcefn clone(&self) -> WeightSlot
fn clone(&self) -> WeightSlot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WeightSlot
impl Debug for WeightSlot
Sourceimpl PartialEq for WeightSlot
impl PartialEq for WeightSlot
Sourcefn eq(&self, other: &WeightSlot) -> bool
fn eq(&self, other: &WeightSlot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for WeightSlot
impl StructuralPartialEq for WeightSlot